@@ -518,8 +518,11 @@ plot_ts <- function(data, decoding, colors, events) {
   if (!controls[["hierarchy"]]) {
     ymin <- min(data[["data"]])
     ymax <- max(data[["data"]])
+    if (ymin > 0 && ymax < 10) {
+      ymin <- 0
+    }
     plot(x_values, data[["data"]],
-      type = "h", col = "lightgrey",
+      type = "l", col = "lightgrey",
       xlab = "", ylab = "", xaxt = "n", yaxt = "n",
       xlim = c(xmin, xmax), ylim = c(ymin, ymax * ymax_factor)
     )
